<?php
function alhana_setup() {
	load_theme_textdomain( 'alhana', get_template_directory() . '/languages' );
	add_editor_style();
	add_theme_support( 'automatic-feed-links' );
	register_nav_menu( 'primary', __( 'Primary Menu', 'alhana' ) );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'custom-background', array( 'default-color' => 'ffffff' ) );
	$args = array( 'default-text-color' => '#e7e7e7', 'default-image' => '', 'height' => 150, 'width' => 325, 'max-width' => 325, 'flex-height' => true, 'flex-width' => false, 'random-default' => false, 'wp-head-callback' => 'alhana_header_style', 'admin-head-callback' => 'alhana_admin_header_style', 'admin-preview-callback' => 'alhana_admin_header_image' );
	add_theme_support( 'custom-header', $args );
}
add_action( 'after_setup_theme', 'alhana_setup' );

function alhana_header_style() {
	$text_color = get_header_textcolor();
	$header_image = get_header_image();
	if ( $text_color == get_theme_support( 'custom-header', 'default-text-color' ) )
		return;
	?>
<style type="text/css">
<?php if (!empty($header_image)) : ?>
.logo-image {background: url(<?php echo esc_url( $header_image ); ?>); width: <?php echo get_custom_header()->width; ?>px; height: <?php echo get_custom_header()->height; ?>px;}
<?php endif; ?>
<?php if (!display_header_text()) { ?>
	.site-title, .site-description {position: absolute !important; clip: rect(1px 1px 1px 1px); /* IE7 */ clip: rect(1px, 1px, 1px, 1px);}
<?php } else { ?>
	.site-title a:link, .site-title a:visited, .menu-item a:hover, .menu-item a:active {color: #<?php echo $text_color; ?>;}
	.site-title a:hover, .site-title a:active {color: #ffffff;}
<?php } ?>
</style>
	<?php
}

function alhana_admin_header_style() {
	$text_color = get_header_textcolor();
?>
	<style type="text/css">
	.appearance_page_custom-header #headimg {border: none; width: 325px; clear: both; overflow: hidden; background: #222222;}
	.logo-image {position: relative; margin: 0 0 20px;}
	.site-title {font: 700 oblique 3.5em/100% Arial, sans-serif; text-transform: uppercase; padding: 0 20px; margin: 0 0 20px;}
	.site-title a:link, .site-title a:visited {color: #<?php echo $text_color; ?>; text-decoration: none; transition: color 0.5s; text-shadow: 1px 1px 1px #000000;}
	.site-title a:hover, .site-title a:active {color: #ffffff;}
	.site-description {font: 300 italic 1.4em/100% Arial, sans-serif; color: #999999; padding: 0 20px; text-align: right; margin: 0 0 40px;}
	#headimg img {position:relative; max-width: <?php echo get_theme_support( 'custom-header', 'max-width' ); ?>px; height: auto;}
	</style>
<?php
}
function alhana_admin_header_image() {
	$header_image = get_header_image();
?>
<div id="headimg">
<?php if ( !empty( $header_image ) ) { ?>
	<img class="logo-image" src="<?php echo esc_url( $header_image ); ?>" class="header-image" width="<?php echo get_custom_header()->width; ?>" height="<?php echo get_custom_header()->height; ?>" alt="" />
<?php } ?>
	<p class="site-title"><a id="name" onclick="return false;" href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php bloginfo( 'name' ); ?></a></p>
	<p class="site-description"><?php bloginfo( 'description' ); ?></p>		
</div>
<?php }

if ( ! isset( $content_width ) ) $content_width = 1280;

function alhana_scripts_styles() {
	global $wp_styles;
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );
	wp_enqueue_script( 'prefixfree', get_template_directory_uri().'/js/prefixfree.min.js', array( 'jquery' ), FALSE );
	wp_enqueue_script( 'custom', get_template_directory_uri().'/custom-script.js', array( 'jquery' ), FALSE );
	wp_enqueue_script( 'scrollscript', get_template_directory_uri().'/js/jquery.mCustomScrollbar.concat.min.js', array( 'jquery' ), FALSE );
	wp_enqueue_style( 'fontawesome', get_template_directory_uri().'/font-awesome.min.css' );
	wp_enqueue_style( 'scrollcss', get_template_directory_uri().'/js/jquery.mCustomScrollbar.css' );
	wp_enqueue_style( 'alhana-style', get_stylesheet_uri() );
}
add_action( 'wp_enqueue_scripts', 'alhana_scripts_styles' );

function alhana_wp_title( $title, $sep ) {
	global $paged, $page;
	if ( is_feed() )
		return $title;
	$title .= get_bloginfo( 'name' );
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		$title = "$title $sep $site_description";
	if ( $paged >= 2 || $page >= 2 )
		$title = "$title $sep " . sprintf( __( 'Page %s', 'alhana' ), max( $paged, $page ) );
	return $title;
}
add_filter( 'wp_title', 'alhana_wp_title', 10, 2 );

function alhana_widgets_init() {
	register_sidebar( array(
		'name' => __( 'Main Sidebar', 'alhana' ),
		'id' => 'sidebar-1',
		'description' => __( 'Appears on Front Page, which has its own widgets', 'alhana' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	register_sidebar( array(
		'name' => __( 'Inner Sidebar', 'alhana' ),
		'id' => 'sidebar-2',
		'description' => __( 'Appears on posts and pages except the Front Page', 'alhana' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
}
add_action( 'widgets_init', 'alhana_widgets_init' );

if ( ! function_exists( 'alhana_content_nav' ) ) :
function alhana_content_nav( $html_id ) {
	global $wp_query;
	$html_id = esc_attr( $html_id );
	if ( $wp_query->max_num_pages > 1 ) : ?>
		<nav id="<?php echo $html_id; ?>" class="archive-nav" role="navigation">
			<span class="nav-previous"><?php next_posts_link( __( ' Older posts', 'alhana' ) ); ?></span><span class="nav-map"><a href="<?php echo esc_url( get_category_link( '1' ) ); ?>" title="<?php _e( 'Posts archive', 'alhana' ); ?>"><i class="icon-list"></i></a></span><span class="nav-next"><?php previous_posts_link( __( 'Newer posts ', 'alhana' ) ); ?></span>
		</nav>
	<?php endif;
}
endif;

if ( ! function_exists( 'alhana_comment' ) ) :
function alhana_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
	?>
	<li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>">
		<p><?php _e( 'Pingback:', 'alhana' ); ?> <?php comment_author_link(); ?> <?php edit_comment_link( __( '(Edit)', 'alhana' ), '<span class="edit-link">', '</span>' ); ?></p>
	<?php
			break;
		default :
		global $post;
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<article id="comment-<?php comment_ID(); ?>">
			<header class="comment-meta comment-author vcard">
				<?php
					echo get_avatar( $comment, 50 );
					echo '<cite class="fn">'.get_comment_author_link().'</cite>';
				?>
				<p class="comment-add">
					<?php edit_comment_link( __( 'Edit', 'alhana' ), '<span class="smallblack"><i class="icon-pencil"></i>', '</span>' ); ?>
					<?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( 'Reply', 'alhana' ), 'before' => '<span class="smallblack"><i class="icon-reply icon-flip-vertical"></i>', 'after' => '</span>', 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
					<?php printf( '<i class="icon-calendar-empty"></i>'.get_comment_date( 'd.m.Y' )); ?>
				</p>
			</header>
			<section class="comment-content comment">
				<?php if ( '0' == $comment->comment_approved ) : ?>
					<p class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'alhana' ); ?></p>
				<?php endif; ?>
				<?php comment_text(); ?>
			</section>
		</article>
	<?php
		break;
	endswitch;
}
endif;

function custom_category_on_homepage( $query ) {
    if ( $query->is_home() && $query->is_main_query() ) {
        $query->set( 'cat', '1' );
    }
}
add_action( 'pre_get_posts', 'custom_category_on_homepage' );

function get_alhana_archive($show_comment_count=0, $show_cat_slug='bez-rubriki', $year=0, $post_type='post', $limit=100){  
    global $month, $wpdb;  
    $result = '';  
    if($year) $AND_year = " AND YEAR(post_date)='$year'";  
    if($limit) $LIMIT = " LIMIT $limit";  
    $arcresults = $wpdb->get_results("SELECT DISTINCT YEAR(post_date) AS year, MONTH(post_date) AS month, count(ID) as posts FROM " . $wpdb->posts . " WHERE post_type='$post_type' AND post_status='publish' GROUP BY YEAR(post_date), MONTH(post_date) ORDER BY post_date DESC");  
    if($arcresults){  
        foreach($arcresults as $arcresult) {
            $text = sprintf('%s %d', $month[zeroise($arcresult->month,2)], $arcresult->year); 
            $result .= '<h4 class="archive-subheading"><i class="icon-calendar-empty"></i>'.$text.'</h4>';
            $thismonth = zeroise($arcresult->month,2);  
            $thisyear = $arcresult->year;  
			$arcresults2 = $wpdb->get_results("SELECT ID, post_date, post_title, comment_status, guid, comment_count FROM " . $wpdb->posts . " WHERE post_date LIKE '$thisyear-$thismonth-%' AND post_status='publish' AND post_type='$post_type' AND post_password='' ORDER BY post_date DESC $LIMIT");  
			if ($arcresults2){  
				$result .= "<ul class=\"postspermonth\">\n";  
				foreach ($arcresults2 as $arcresult2) {
					$checkcat = get_the_category( $arcresult2->ID );
					if (!empty($checkcat) && ($checkcat[0]->category_nicename == $show_cat_slug)) { if ($arcresult2->post_date != '0000-00-00 00:00:00') {
						$url = get_permalink($arcresult2->ID);
						$arc_title = $arcresult2->post_title;  
						if ($arc_title) $text = strip_tags($arc_title);  
						else $text = $arcresult2->ID;
						if($show_comment_count){  
							$cc = $arcresult2->comment_count;  
							if ($arcresult2->comment_status == "open" OR $comments_count > 0) $text .= " |&nbsp;$cc<i class='icon-comments'></i>";  
						}
						$result .= "<li>". get_archives_link($url, $text, '');  
						$result .= "</li>\n";  
					} }
				}  
				$result .= "</ul><div style='clear: both;'></div>\n";  
			}  
        }  
	}  
    return $result;  
}

#Уничтожение автотрекбэков
function kama_disable_inner_ping( &$links ){  
    $site_url = home_url();  
    foreach ( $links as $key => $val )  
        if ( strpos( $val, $site_url ) !== false ) unset($links[$key]);  
}  
add_action( 'pre_ping', 'kama_disable_inner_ping' ); 
?>